@@ -3,8 +3,10 @@
 #'
 #' @description Estimates the mode for a vector
 #'
-#' @param x A data vector
-#' @param na.rm A logical value, default is \code{FALSE}
+#' @param x An \R object.
+#' @param na.rm A logical value indicating whether \code{NA}
+#'  should be stripped before the computation proceeds. Default
+#'  is \code{FALSE}
 #' @note This function replaces the \code{base} function of the same name, while \code{SciencesPo::mode} calculates the \dQuote{mode}, \code{base::mode} prints the \dQuote{class} of an object.
 #'
 #' @author Daniel Marcelino, \email{dmarcelino@@live.com}
@@ -15,6 +17,11 @@
 #'
 #' Mode(myvar, FALSE)
 #' @export
+#' @rdname Mode
+`Mode` <- function(x, na.rm = FALSE) UseMethod("Mode")
+
+#' @export
+#' @rdname Mode
 `Mode` <- function(x, na.rm = FALSE) {
   if(na.rm){
     x = base::subset(x, !is.na(x))
@@ -25,3 +32,7 @@
   return(as.numeric(mode) )
 }
 NULL
+
+#' @export
+#' @rdname Mode
+`Mode.data.frame` <- function(x, na.rm = TRUE) sapply(x, Mode)
