@@ -1,7 +1,7 @@
 #' @encoding UTF-8
 #' @title  Calculate breaks
 #'
-#' Calculate breaks according to the Herbert Sturges' (1926) formula
+#' @description Calculate breaks according to the Herbert Sturges' (1926) formula
 #'
 #' @param x A vector of count values.
 #'
@@ -14,7 +14,7 @@
 #' sturges(y)
 #'
 #' @export
-sturges=function(x)
+sturges <- function(x)
 {
   N    = length(x)
   K    = 1+log2(N)
@@ -26,4 +26,5 @@ sturges=function(x)
   if (max(classes ) < max(x)) { classes [length(classes )+1]=max(classes )+range }
   if (length(which(classes  >= max(x))) > 1) { classes  = classes [-length(classes )] }
   classes
-}
+}### end -- sturges function
+NULL
