@@ -4,13 +4,12 @@
 #'
 #' @param y the dependent variable in [0, 1] interval.
 #' @references
-#' Smithson M, Verkuilen J (2006) A Better Lemon Squeezer? Maximum-Likelihood Regres- sion with Beta-Distributed Dependent Variables. \emph{Psychological Methods}, 11(1), 54-71.
+#' Smithson M, Verkuilen J (2006) A Better Lemon Squeezer? Maximum-Likelihood Regression with Beta-Distributed Dependent Variables. \emph{Psychological Methods}, 11(1), 54-71.
 #'
-#' @seealso  \code{\link{normalize}},  \code{\link{new.range}}.
+#' @seealso  \code{\link{normalize}}.
 #' @examples
-#'  x <- sample(10);
-#'  y <- normalize(x, range=c(0,1));
-#'  y;
+#'  x <- sample(10); x;
+#'  y <- normalize(x); y;
 #'  svTransform(y)
 #' @export
 `svTransform` <- function(y)
@@ -18,5 +17,5 @@
   n <- length(y)
   trans <- (y * (n-1) + 0.5)/n
   return(trans)
-}
+}### end -- svTransform function
 NULL
